==> dicejinni_0.3.20090322-1.tar.gz: dicejinni-0.3.20090322/src/DiceSetList.cpp <==
/*
  DiceJinni - A dice simulator
  Copyright (C) 2008  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "DiceSetList.h"

#include <Lum/Base/L10N.h>
#include <Lum/Base/String.h>

#include <Lum/Button.h>
#include <Lum/ButtonRow.h>
#include <Lum/Panel.h>
#include <Lum/Table.h>

#include "Configuration.h"
#include "DiceSetEdit.h"

DiceSetList::DiceSetList()
 : selection(new Lum::Model::SingleLineSelection()),
   addAction(new Lum::Model::Action()),
   editAction(new Lum::Model::Action()),
   removeAction(new Lum::Model::Action())
{
  EvaluateRights();

  Observe(selection);

  Observe(addAction);
  Observe(editAction);
  Observe(removeAction);

  Observe(GetClosedAction());
}

void DiceSetList::EvaluateRights()
{
  if (selection.Valid() && selection->HasSelection()) {
    editAction->Enable();
    removeAction->Enable();
  }
  else {
    editAction->Disable();
    removeAction->Disable();
  }
}

Lum::Object* DiceSetList::GetContent()
{
  Lum::Panel            *panel,*horiz;
  Lum::Table            *table;
  Lum::Model::HeaderRef headerModel;

  panel=Lum::VPanel::Create(true,true);

  horiz=Lum::HPanel::Create(true,true);

  headerModel=new Lum::Model::HeaderImpl();
  headerModel->AddColumn(L"Name",Lum::Base::Size::stdCharWidth,20,true);

  table=new Lum::Table();
  table->SetFlex(true,true);
  table->SetHeight(Lum::Base::Size::stdCharHeight,10);
  table->SetShowHeader(true);
  table->GetTableView()->SetAutoHSize(true);
  table->GetTableView()->SetAutoFitColumns(true);
  table->SetModel(setsModel);
  table->SetHeaderModel(headerModel);
  table->SetSelection(selection);
  table->SetDoubleClickAction(editAction);
  horiz->Add(table);

  horiz->AddSpace();
  horiz->Add(Lum::VPanel::Create(false,true)
             ->Add(Lum::Button::Create(_(L"BTN_ADD",L"_Add"),addAction,true,false))
             ->AddSpace()
             ->Add(Lum::Button::Create(_(L"BTN_UPDATE",L"_Edit"),editAction,true,false))
             ->AddSpace()
             ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));

  panel->Add(horiz);

  return panel;
}

void DiceSetList::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
{
  Lum::Dlg::ActionDialog::CreateActionInfosOk(actions,GetClosedAction());
}

void DiceSetList::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
{
  if (model==GetClosedAction() && GetClosedAction()->IsFinished()) {
    Exit();
  }
  else if (model==selection && dynamic_cast<const Lum::Model::Selection::Selected*>(&msg)!=NULL) {
    EvaluateRights();
  }
  else if (model==addAction && addAction->IsFinished()) {
    DiceSetEdit *dialog;

    DiceSet     diceSet;

    dialog=new DiceSetEdit(diceSet);
    dialog->SetParent(this);
    if (dialog->Open()) {
      dialog->EventLoop();
      dialog->Close();

      if (dialog->GetResult()) {
        // Redraw entry because its name has changed...
        setsModel->Append(diceSet);
        EvaluateRights();
        configurationChanged=true;
      }
    }

    delete dialog;
  }
  else if (model==editAction && editAction->IsFinished() && editAction->IsEnabled()) {
    assert(selection->HasSelection());

    DiceSetEdit *dialog;

    dialog=new DiceSetEdit(setsModel->GetEntry(selection->GetLine()));
    dialog->SetParent(this);
    if (dialog->Open()) {
      dialog->EventLoop();
      dialog->Close();

      if (dialog->GetResult()) {
        // Redraw entry because its name has changed...
        setsModel->RedrawRow(selection->GetLine());
        EvaluateRights();
        configurationChanged=true;
      }
    }

    delete dialog;
  }
  else if (model==removeAction && removeAction->IsFinished() && removeAction->IsEnabled()) {
    assert(selection->HasSelection());

    setsModel->Delete(selection->GetLine());
    EvaluateRights();
    configurationChanged=true;
  }

  Lum::Dlg::ActionDialog::Resync(model,msg);
}

==> dicejinni_0.4.20100104-1.tar.gz: dicejinni-0.4.20100104/src/DiceSetList.cpp <==
/*
  DiceJinni - A dice simulator
  Copyright (C) 2008  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "DiceSetList.h"

#include <Lum/Base/L10N.h>
#include <Lum/Base/String.h>

#include <Lum/Button.h>
#include <Lum/ButtonRow.h>
#include <Lum/Panel.h>
#include <Lum/Table.h>

#include "Configuration.h"
#include "DiceSetEdit.h"

DiceSetList::DiceSetList()
 : selection(new Lum::Model::SingleLineSelection()),
   addAction(new Lum::Model::Action()),
   editAction(new Lum::Model::Action()),
   removeAction(new Lum::Model::Action())
{
  EvaluateRights();

  Observe(selection);

  Observe(addAction);
  Observe(editAction);
  Observe(removeAction);

  Observe(GetClosedAction());
}

void DiceSetList::EvaluateRights()
{
  if (selection.Valid() && selection->HasSelection()) {
    editAction->Enable();
    removeAction->Enable();
  }
  else {
    editAction->Disable();
    removeAction->Disable();
  }
}

Lum::Object* DiceSetList::GetContent()
{
  Lum::Panel            *panel,*horiz;
  Lum::Table            *table;
  Lum::Model::HeaderRef headerModel;

  panel=Lum::VPanel::Create(true,true);

  horiz=Lum::HPanel::Create(true,true);

  headerModel=new Lum::Model::HeaderImpl();
  headerModel->AddColumn(L"Name",Lum::Base::Size::stdCharWidth,20,true);

  table=new Lum::Table();
  table->SetFlex(true,true);
  table->SetWidth(Lum::Base::Size::stdCharWidth,20);
  table->SetHeight(Lum::Base::Size::stdCharHeight,10);
  table->SetShowHeader(false);
  table->GetTableView()->SetAutoHSize(true);
  table->GetTableView()->SetAutoFitColumns(true);
  table->SetModel(setsModel);
  table->SetHeaderModel(headerModel);
  table->SetSelection(selection);
  table->SetDoubleClickAction(editAction);
  horiz->Add(table);

  horiz->AddSpace();
  horiz->Add(Lum::VPanel::Create(false,true)
             ->Add(Lum::Button::Create(_(L"BTN_ADD",L"_Add"),addAction,true,false))
             ->AddSpace()
             ->Add(Lum::Button::Create(_(L"BTN_UPDATE",L"_Edit"),editAction,true,false))
             ->AddSpace()
             ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));

  panel->Add(horiz);

  return panel;
}

void DiceSetList::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
{
  Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
}

void DiceSetList::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
{
  if (model==GetClosedAction() && GetClosedAction()->IsFinished()) {
    Exit();
  }
  else if (model==selection && dynamic_cast<const Lum::Model::Selection::Selected*>(&msg)!=NULL) {
    EvaluateRights();
  }
  else if (model==addAction && addAction->IsFinished()) {
    DiceSetEdit *dialog;

    DiceSet     diceSet;

    dialog=new DiceSetEdit(diceSet);
    dialog->SetParent(this);
    if (dialog->Open()) {
      dialog->EventLoop();
      dialog->Close();

      if (dialog->GetResult()) {
        // Redraw entry because its name has changed...
        setsModel->Append(diceSet);
        EvaluateRights();
        configurationChanged=true;
      }
    }

    delete dialog;
  }
  else if (model==editAction && editAction->IsFinished() && editAction->IsEnabled()) {
    assert(selection->HasSelection());

    DiceSetEdit *dialog;

    dialog=new DiceSetEdit(setsModel->GetEntry(selection->GetLine()));
    dialog->SetParent(this);
    if (dialog->Open()) {
      dialog->EventLoop();
      dialog->Close();

      if (dialog->GetResult()) {
        // Redraw entry because its name has changed...
        setsModel->RedrawRow(selection->GetLine());
        EvaluateRights();
        configurationChanged=true;
      }
    }

    delete dialog;
  }
  else if (model==removeAction &&
           removeAction->IsFinished() &&
           removeAction->IsEnabled()) {
    assert(selection->HasSelection());

    setsModel->Delete(selection->GetLine());
    currentSet->Off();

    EvaluateRights();
    configurationChanged=true;
  }

  Lum::Dlg::ActionDialog::Resync(model,msg);
}
